@@ -42,7 +42,7 @@ lazy_static! {
 #[derive(Deserialize)]
 #[derive(Debug)]
 #[derive(Hash)]
-pub enum SourceType {
+pub enum FlatpakSourceType {
     Archive,
     Git,
     Bazaar,
@@ -54,75 +54,75 @@ pub enum SourceType {
     Patch,
     ExtraData,
 }
-impl Default for SourceType {
+impl Default for FlatpakSourceType {
     fn default() -> Self {
-        SourceType::Archive
+        FlatpakSourceType::Archive
     }
 }
-impl SourceType {
+impl FlatpakSourceType {
     pub fn to_string(&self) -> String {
         match &self {
-            Archive => ARCHIVE.to_string(),
-            Git => GIT.to_string(),
-            Bazaar => BAZAAR.to_string(),
-            Svn => SVN.to_string(),
-            Dir => DIR.to_string(),
-            File => FILE.to_string(),
-            Script => SCRIPT.to_string(),
-            Shell => SHELL.to_string(),
-            Patch => PATCH.to_string(),
-            ExtraData => EXTRA_DATA.to_string(),
+            FlatpakSourceType::Archive => ARCHIVE.to_string(),
+            FlatpakSourceType::Git => GIT.to_string(),
+            FlatpakSourceType::Bazaar => BAZAAR.to_string(),
+            FlatpakSourceType::Svn => SVN.to_string(),
+            FlatpakSourceType::Dir => DIR.to_string(),
+            FlatpakSourceType::File => FILE.to_string(),
+            FlatpakSourceType::Script => SCRIPT.to_string(),
+            FlatpakSourceType::Shell => SHELL.to_string(),
+            FlatpakSourceType::Patch => PATCH.to_string(),
+            FlatpakSourceType::ExtraData => EXTRA_DATA.to_string(),
         }
     }
-    pub fn from_string(source_type: &str) -> Result<SourceType, String> {
+    pub fn from_string(source_type: &str) -> Result<FlatpakSourceType, String> {
         if source_type == ARCHIVE {
-            return Ok(SourceType::Archive);
+            return Ok(FlatpakSourceType::Archive);
         }
         if source_type == GIT {
-            return Ok(SourceType::Git);
+            return Ok(FlatpakSourceType::Git);
         }
         if source_type == BAZAAR {
-            return Ok(SourceType::Bazaar);
+            return Ok(FlatpakSourceType::Bazaar);
         }
         if source_type == SVN {
-            return Ok(SourceType::Svn);
+            return Ok(FlatpakSourceType::Svn);
         }
         if source_type == DIR {
-            return Ok(SourceType::Dir);
+            return Ok(FlatpakSourceType::Dir);
         }
         if source_type == FILE {
-            return Ok(SourceType::File);
+            return Ok(FlatpakSourceType::File);
         }
         if source_type == SCRIPT {
-            return Ok(SourceType::Script);
+            return Ok(FlatpakSourceType::Script);
         }
         if source_type == SHELL {
-            return Ok(SourceType::Shell);
+            return Ok(FlatpakSourceType::Shell);
         }
         if source_type == PATCH {
-            return Ok(SourceType::Patch);
+            return Ok(FlatpakSourceType::Patch);
         }
         if source_type == EXTRA_DATA {
-            return Ok(SourceType::ExtraData);
+            return Ok(FlatpakSourceType::ExtraData);
         }
         Err(format!("Invalid source type {}.", source_type))
     }
 }
 
-pub fn serialize_to_string<S>(x: &SourceType, s: S) -> Result<S::Ok, S::Error>
+pub fn serialize_to_string<S>(x: &FlatpakSourceType, s: S) -> Result<S::Ok, S::Error>
 where
     S: Serializer,
 {
     s.serialize_str(&x.to_string())
 }
 
-pub fn deserialize_from_string<'de, D>(deserializer: D) -> Result<SourceType, D::Error>
+pub fn deserialize_from_string<'de, D>(deserializer: D) -> Result<FlatpakSourceType, D::Error>
 where
     D: Deserializer<'de>,
 {
     let buf = String::deserialize(deserializer)?;
 
-    SourceType::from_string(&buf).map_err(serde::de::Error::custom)
+    FlatpakSourceType::from_string(&buf).map_err(serde::de::Error::custom)
 }
 
 #[derive(Clone)]
@@ -242,7 +242,7 @@ impl FlatpakSourceItem {
     pub fn supports_mirror_urls(&self) -> bool {
         let type_name = self.get_type_name();
         // FIXME why are mirror urls not supported for types git, svn and bzr.
-        if type_name == "archive" || type_name == "file" {
+        if type_name == ARCHIVE || type_name == FILE {
             return true;
         }
         return false;
@@ -451,49 +451,6 @@ impl FlatpakSource {
         None
     }
 
-    // The logic of this functions is based on the code from BuilderArchiveType.get_type
-    // in the flatpak-builder project.
-    pub fn detect_archive_type(url: &str) -> Option<String> {
-        let url = url.to_lowercase();
-        if url.ends_with(".tar") {
-            return Some("tar".to_string());
-        }
-        if url.ends_with(".tar.gz") || url.ends_with(".tgz") || url.ends_with(".taz") {
-            return Some("tar-gzip".to_string());
-        }
-        if url.ends_with(".tar.z") || url.ends_with(".taz") {
-            return Some("tar-compress".to_string());
-        }
-        if url.ends_with(".tar.bz2") || url.ends_with(".tz2") {
-            return Some("tar-bzip2".to_string());
-        }
-        if url.ends_with(".tbz2") || url.ends_with(".tbz") {
-            return Some("tar-bzip2".to_string());
-        }
-        if url.ends_with(".tar.lz") {
-            return Some("tar-lzip".to_string());
-        }
-        if url.ends_with(".tar.lzma") || url.ends_with(".tlz") {
-            return Some("tar-lzma".to_string());
-        }
-        if url.ends_with(".tar.lzo") {
-            return Some("tar-lzop".to_string());
-        }
-        if url.ends_with(".tar.xz") || url.ends_with(".txz") {
-            return Some("tar-xz".to_string());
-        }
-        if url.ends_with(".zip") {
-            return Some("zip".to_string());
-        }
-        if url.ends_with(".rpm") {
-            return Some("rpm".to_string());
-        }
-        if url.ends_with(".7z") {
-            return Some("sevenz".to_string());
-        }
-        None
-    }
-
     pub fn file_path_matches(path: &str) -> bool {
         // The file path for a module is not necessarily in reverse DNS, so we can only test
         // for the extension of the file.
@@ -588,9 +545,6 @@ impl FlatpakSource {
     }
 
     pub fn is_valid(&self) -> Result<(), String> {
-        if self.r#type.is_none() {
-            return Err("Required top-level field type is missing from Flatpak source.".to_string());
-        }
         if let Some(source_type) = &self.r#type {
             if !SOURCE_TYPES.contains(&source_type) {
                 return Err(format!("Invalid source type {}.", source_type));
@@ -629,7 +583,7 @@ mod tests {
     use super::*;
 
     #[test]
-    pub fn test_parse_single_source() {
+    pub fn test_parse_single_source_manifest() {
         match FlatpakSource::parse(
             "source.yaml",
             r###"
@@ -637,7 +591,7 @@ mod tests {
             path: apply_extra.sh
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(source) => {
                 assert_eq!(source.path, Some("apply_extra.sh".to_string()));
             }
@@ -645,7 +599,7 @@ mod tests {
     }
 
     #[test]
-    pub fn test_parse_multiple_sources() {
+    pub fn test_parse_multiple_source_manifests() {
         match FlatpakSource::parse_many(
             "source.yaml",
             r###"
@@ -673,7 +627,7 @@ mod tests {
                 url-pattern: download_link_deb\s*=\s*"(http[s]?://[\w\d$-_@.&+]+)"
             "###,
         ) {
-            Err(e) => panic!(e),
+            Err(e) => std::panic::panic_any(e),
             Ok(sources) => {
                 assert_eq!(sources.len(), 4);
                 let last_source = sources.last().unwrap();
@@ -681,4 +635,39 @@ mod tests {
             }
         }
     }
+
+    #[test]
+    pub fn test_parse_invalid_source_type() {
+        let source_manifest = r###"
+            type: not_a_valid_source_type
+            path: apply_extra.sh
+        "###;
+        match FlatpakSource::parse("source.yaml", source_manifest) {
+            Ok(_source) => {
+                panic!("We should not be able to parse a source manifest with an invalid source type");
+            }
+            Err(e) => {
+                assert!(e.to_string().contains("Invalid source type"));
+            }
+        }
+    }
+
+    #[test]
+    pub fn test_parse_missing_source_type() {
+        let source_manifest = r###"
+            url: "https://ftp.gnu.org/gnu/gcc/gcc-7.5.0/gcc-7.5.0.tar.xz"
+            sha256: "b81946e7f01f90528a1f7352ab08cc602b9ccc05d4e44da4bd501c5a189ee661"
+        "###;
+        match FlatpakSource::parse("source.yaml", source_manifest) {
+            Ok(source) => {
+                assert!(source.url.is_some());
+            }
+            Err(e) => {
+                panic!(
+                    "We should be able to parse a source manifest without a source type: {}",
+                    e
+                );
+            }
+        }
+    }
 }
